:orphan:

Examples using treeple
==========================

To be able to effectively use treeple, look at some of the examples here
to learn everything you need!

.. rstcheck: ignore-next-code-block
.. include:: auto_examples/index.rst
   :start-after: :orphan:
